summaryrefslogtreecommitdiffstats
path: root/ash/shell.h
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-11-15 20:17:39 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-11-15 20:17:39 +0000
commitdc0973937acc74340adba60e690d016acad041ff (patch)
treec83e80ebfd158e96084e6b43d8498ee6e234a9c1 /ash/shell.h
parent56adad67862f17d484c6349ce0991e4e19871ed5 (diff)
downloadchromium_src-dc0973937acc74340adba60e690d016acad041ff.zip
chromium_src-dc0973937acc74340adba60e690d016acad041ff.tar.gz
chromium_src-dc0973937acc74340adba60e690d016acad041ff.tar.bz2
Separates some ash-specific logic from the ActivationController in preparation for moving it to views/corewm.
http://crbug.com/158115 R=sky@chromium.org Review URL: https://codereview.chromium.org/11420010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@168005 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/shell.h')
-rw-r--r--ash/shell.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ash/shell.h b/ash/shell.h
index db67eb6..db4b5c0 100644
--- a/ash/shell.h
+++ b/ash/shell.h
@@ -213,8 +213,8 @@ class ASH_EXPORT Shell : internal::SystemModalContainerEventFilterDelegate,
// Returns true if the screen is locked.
bool IsScreenLocked() const;
- // Returns true if a modal dialog window is currently open.
- bool IsModalWindowOpen() const;
+ // Returns true if a system-modal dialog window is currently open.
+ bool IsSystemModalWindowOpen() const;
// For testing only: set simulation that a modal window is open
void SimulateModalWindowOpenForTesting(bool modal_window_open) {